# Copyright 2013 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

"""Argument parser for `maastest.main`."""

from __future__ import (
    absolute_import,
    print_function,
    unicode_literals,
    )

__metaclass__ = type
__all__ = [
    "prepare_parser",
    ]

import argparse

from six import text_type


class MAASTestArgumentParser(argparse.ArgumentParser):

    def parse_args(self):
        args = super(MAASTestArgumentParser, self).parse_args()
        bmc_details = (args.bmc_mac, args.bmc_username, args.bmc_password)
        if args.interactive_enlistment:
            if bmc_details != (None, None, None):
                self.error(
                    "None of the BMC details should be provided when using "
                    "--interactive-enlistment.")
        else:
            if None in bmc_details:
                self.error(
                    "All the BMC details (MAC address, username "
                    "and password) must be provided.")
        return args


def prepare_parser():
    # TODO: This is not tested sinc how maas-test will interface with
    # checkbox is still in flux.  Right now, this is just to get the
    # testing going.
    parser = MAASTestArgumentParser(
        description="Test whether or not a node is compatible with MAAS.")

    parser.add_argument(
        'interface', type=text_type,
        help="The interface on which MAAS will provide DHCP. This is "
             "the machine's interface on which the node under test should "
             "be plugged-in.")
    parser.add_argument(
        '--ppa', type=text_type, default=None,
        help="An optional PPA name.  If provided, that PPA will be "
             "added onto the virtual machine.  This is typically used to "
             "test recent versions of MAAS only published in a PPA ("
             "e.g. ppa:maas-maintainers/dailybuilds).")
    parser.add_argument(
        '--interactive-enlistment', action='store_true',
        help="Perform an interactive enlistment. Instead of passing the "
             "BMC details on the command line, the node will have to be "
             "powered up manually.")
    # BMC details.
    parser.add_argument(
        '--bmc-mac', type=text_type,
        help="The MAC address of the node's BMC. This will be used to "
             "power up the node to enlist it.")
    parser.add_argument(
        '--bmc-username', type=text_type,
        help="The username to use when authenticating with the node's BMC. "
             "This will be used to power up the node to enlist it.")
    parser.add_argument(
        '--bmc-password', type=text_type,
        help="The password to use when authenticating with the node's BMC. "
             "This will be used to power up the node to enlist it.")

    return parser
